/*
Licensed Materials - Property of IBM
IBM WebSphere CloudBurst Appliance (9235-72X)
Copyright IBM Corporation 2015. All Rights Reserved.
US Government Users Restricted Rights - Use, duplication or disclosure
restricted by GSA ADP Schedule Contract with IBM Corp.
*/

import com.ibm.websphere.rest.RESTUtils;
import com.ibm.ws.objectgrid.security.block.HostBlocker;
import com.ibm.ws.objectgrid.security.block.HostBlocker.BlockedHostEntry;

def onDeleteCollection()
{
	if (!RESTUtils.authorized())
        return com.ibm.websphere.rest.RenderUtils.renderError(403, 'RM08008');
        
    //
    // Unblock xs.app.
    // 
    HostBlocker.unblock("");
    
    request.status = 204;
}

def onDelete()
{
	if (!RESTUtils.authorized())
        return com.ibm.websphere.rest.RenderUtils.renderError(403, 'RM08008');
        
    def host = request.params.hostblockerId[];
    
    //
    // Unblock xs.app.
    // 
    HostBlocker.unblock(host);
    
    request.status = 204;
}

def onList() {
	if (!RESTUtils.authorized())
        return com.ibm.websphere.rest.RenderUtils.renderError(403, 'RM08008');

    //
    // Map of results.
    //
    Map<String, Map<String, String>> results = new HashMap<String, Map<String, String>>();
    def now = System.currentTimeMillis();
    
    //
    // Get xs.app's results.
    //
    Map<String, BlockedHostEntry> blocked = HostBlocker.getBlockedHosts();
    Map<String, String> xsApp = new HashMap<String, String>();
    for (String host : blocked.keySet()) {
        def delta = blocked.get(host).blockedUntil - now;
         
        if (delta > 0) {
            def hours = Math.floor(delta / 3600000);
            def mins  = Math.floor((delta - (hours * 3600000)) / 60000);
            def secs  = Math.floor((delta - (hours * 3600000) - (mins * 60000)) / 1000);
         
            results.put("xs.app", xsApp);
            xsApp.put(host, String.format("%02d:%02d:%02d", (int) hours, (int) mins, (int) secs));
        }
    }


    request.json.output = results;
    request.view = com.ibm.websphere.rest.RenderUtils.getRequestedView(); 
    render();
}
