/*
Licensed Materials - Property of IBM
IBM WebSphere CloudBurst Appliance (9235-72X)
Copyright IBM Corporation 2009. All Rights Reserved.
US Government Users Restricted Rights - Use, duplication or disclosure
restricted by GSA ADP Schedule Contract with IBM Corp.
*/
package groovy.rainmaker.core


// Spins off a closure in a separate thread and periodically invokes
// callback until the closure completes.  This method returns whatever
// the closure returned, or rethrows the exception thrown by the closure.

def whileRunning(callback, period, closure) {
    def nextCB = System.currentTimeMillis() + period

    def rc = null
    def ex = null
    def t = Thread.start {
        try {
            rc = closure()
        }
        catch (e) {
            ex = e
        }
    }

    while (true) {
        t.join(nextCB - System.currentTimeMillis())

        if (! t.isAlive())
            break

        callback()
        nextCB += period
    }

    if (ex)
        throw ex

    return rc
}
