/*
Licensed Materials - Property of IBM
IBM WebSphere CloudBurst Appliance (9235-72X)
Copyright IBM Corporation 2009. All Rights Reserved.
US Government Users Restricted Rights - Use, duplication or disclosure
restricted by GSA ADP Schedule Contract with IBM Corp.
*/

package reset;

import com.ibm.websphere.rainmaker.auditing.AuditDataHelper;
import groovy.rainmaker.constants.Action;
import com.ibm.websphere.rainmaker.logging.CleanStackTrace;
import com.ibm.websphere.rainmaker.logging.MessageUtils;
import com.ibm.websphere.users.Users;

def _renderError(status, msg)
{
    request.status = status;
    request.writer[].write("<span>${MessageUtils.isMessage(msg) ? MessageUtils.message(user.lang[], msg, []) : msg}</span>");
}

def onPOST()
{
    try
    {
        def targetUser = Users.getUserByName(request.params.user[]);

        if (!targetUser)
            return _renderError(404, 'RM10219');
        
        def password = generatePassword(8);
        
        def success = changePassword(targetUser.id, password); 
        if (success == 0) {
            // Audit that the password was successfully changed
        	AuditDataHelper.audit(Action.UPDATE, "submissions" ,
		        MessageUtils.message('RM10220', []));
        
	        request.writer[].write("<span>${MessageUtils.message(user.lang[], 'RM10220', [])}</span>");
        } else if (success == -2) {
            // Audit that the password failed to changed
        	AuditDataHelper.audit(Action.UPDATE, "submissions",
		        MessageUtils.message('RM11170', [targetUser.username]));
        
        	// problem changing password
    		_renderError(500, MessageUtils.message('RM11170', [targetUser.username]));
        } else if (success == -1) {
            // Audit that the password was successfully changed, but email failed to send
        	AuditDataHelper.audit(Action.UPDATE, "submissions",
		        MessageUtils.message('RM11171', [targetUser.username]));
        
        	// problem changing password
    		_renderError(500, MessageUtils.message('RM11171', [targetUser.username]));
        }
        
    }
    
    catch (Throwable t)
    {
        logger.SEVERE { CleanStackTrace.cleanStackTrace(t) };
        _renderError(500, t.message);
    }    
}
